##Pre-loaded libraries and graphing functions to speed things up

library("ggplot2")
library("RColorBrewer")
library("scales")
library(dplyr)
library(tidyr)

source('graphs.R')
source('tables.R')

